@@ -20,6 +20,8 @@
 #include <config.h>
 #endif
 
+#ifdef USE_LDAP
+
 #define _GNU_SOURCE
 
 #include <stdio.h>
@@ -1718,3 +1720,5 @@ ldap_update_gecos (ldap_session_t *session, const char *user,
 
   return rc;
 }
+
+#endif /* USE_LDAP */
