@@ -1,4 +1,4 @@
-/* Copyright (C) 2002 Thorsten Kukuk
+/* Copyright (C) 2002, 2003 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -144,7 +144,7 @@ static void
 print_usage (FILE *stream, const char *program)
 {
   fprintf (stream, _("Usage: %s [-f|-g|-s|-k[-q]] [name]\n"), program);
-  fprintf (stream, _("       %s [-n min] [-x max] [-w warn] [-i inact] user"), program);
+  fprintf (stream, _("       %s [-n min] [-x max] [-w warn] [-i inact] user\n"), program);
   fprintf (stream, _("       %s {-l|-u|-d|-S[-a]|-e|-h} user\n"), program);
 }
 
