@@ -28,14 +28,19 @@
 #include <locale.h>
 #include <libintl.h>
 #include <sys/stat.h>
-#include <ldap.h>
 #include <rpcsvc/yp_prot.h>
 #include <rpcsvc/ypclnt.h>
 #include <security/pam_appl.h>
 #include <security/pam_misc.h>
 
-#include "nsw.h"
+#ifdef USE_LDAP
+#ifdef HAVE_LDAP_H
+#include <ldap.h>
+#endif
 #include "ldapfcn.h"
+#endif
+
+#include "nsw.h"
 #include "yppasswd.h"
 #include "public.h"
 #include "getdef.h"
@@ -63,9 +68,11 @@ nsw2str (service_t service)
     case S_NISPLUS:
       return "NIS+";
       break;
+#ifdef USE_LDAP
     case S_LDAP:
       return "LDAP";
       break;
+#endif
     default:
       return "UNKNOWN";
       break;
@@ -274,6 +281,7 @@ do_getpwnam (const char *user, const char *use_service)
 	      break;
 	    }
 	}
+#ifdef USE_LDAP
       else if (strcasecmp ("ldap", cmpptr) == 0)
 	{
 	  nss_handle = dlopen ("libnss_ldap.so.2", RTLD_NOW);
@@ -307,6 +315,7 @@ do_getpwnam (const char *user, const char *use_service)
 	      break;
 	    }
 	}
+#endif
     }
 
   nsw_free (nswp);
@@ -347,6 +356,7 @@ do_getpwnam (const char *user, const char *use_service)
           return data;
         }
     }
+#ifdef USE_LDAP
   else if (data->service == S_LDAP)
     {
       nss_getspnam_r = dlsym (nss_handle, "_nss_ldap_getspnam_r");
@@ -360,6 +370,7 @@ do_getpwnam (const char *user, const char *use_service)
           return data;
         }
     }
+#endif
 
   if (nss_getspnam_r)
     {
@@ -697,11 +708,12 @@ Error while closing temporary shadow file: %m\n"));
 	  retval = -1;
 	}
     }
+#ifdef USE_LDAP
   else if (data->service == S_LDAP)
     {
       ldap_session_t *session = NULL;
 
-      session = create_ldap_session ("/etc/openldap/ldap.conf");
+      session = create_ldap_session (LDAP_PATH_CONF);
 
       if (session != NULL)
 	{
@@ -720,6 +732,7 @@ Error while closing temporary shadow file: %m\n"));
 		     ldap_err2string (retval));
 	}
     }
+#endif
   else
     fprintf (stderr, _("Unknown service %d\n"), data->service);
 
